@@ -21,21 +21,23 @@ class Argyris(CiarletElement):
         assert reference.name == "triangle"
         dofs = []
         for v_n, vs in enumerate(reference.vertices):
-            dofs.append(PointEvaluation(vs, entity=(0, v_n)))
+            dofs.append(PointEvaluation(reference, vs, entity=(0, v_n)))
             for i in range(reference.tdim):
-                dir = tuple(1 if i == j else 0 for j in range(reference.tdim))
-                dofs.append(PointDirectionalDerivativeEvaluation(vs, dir, entity=(0, v_n)))
+                direction = tuple(1 if i == j else 0 for j in range(reference.tdim))
+                dofs.append(PointDirectionalDerivativeEvaluation(
+                    reference, vs, direction, entity=(0, v_n)))
             for i in range(reference.tdim):
                 for j in range(i + 1):
                     dofs.append(PointComponentSecondDerivativeEvaluation(
-                        vs, (i, j), entity=(0, v_n)))
+                        reference, vs, (i, j), entity=(0, v_n)))
         for e_n, vs in enumerate(reference.sub_entities(1)):
             sub_ref = create_reference(
                 reference.sub_entity_types[1],
                 vertices=[reference.vertices[v] for v in vs])
             midpoint = tuple(sym_sum(i) / len(i)
                              for i in zip(*[reference.vertices[i] for i in vs]))
-            dofs.append(PointNormalDerivativeEvaluation(midpoint, sub_ref, entity=(1, e_n)))
+            dofs.append(PointNormalDerivativeEvaluation(
+                reference, midpoint, sub_ref, entity=(1, e_n)))
 
         super().__init__(
             reference, order, polynomial_set(reference.tdim, 1, order), dofs, reference.tdim, 1
