@@ -16,14 +16,14 @@ class BognerFoxSchmit(CiarletElement):
         assert order == 3
         dofs = []
         for v_n, vs in enumerate(reference.vertices):
-            dofs.append(PointEvaluation(vs, entity=(0, v_n)))
+            dofs.append(PointEvaluation(reference, vs, entity=(0, v_n)))
             for i in range(reference.tdim):
                 dofs.append(DerivativePointEvaluation(
-                    vs, tuple(1 if i == j else 0 for j in range(reference.tdim)),
+                    reference, vs, tuple(1 if i == j else 0 for j in range(reference.tdim)),
                     entity=(0, v_n)))
 
             if reference.tdim == 2:
-                dofs.append(DerivativePointEvaluation(vs, (1, 1), entity=(0, v_n),
+                dofs.append(DerivativePointEvaluation(reference, vs, (1, 1), entity=(0, v_n),
                                                       mapping="identity"))
 
         super().__init__(
