@@ -35,11 +35,11 @@ class DirectSerendipity(DirectElement):
             eta_v = 1
 
             lambda_h = alpha_h * (1 - x[1]) + beta_h * x[1] + gamma_h
-            R_h = -2 * x[1] / ((1 - x[1]) / xi_h + x[1] / eta_h)
+            r_h = -2 * x[1] / ((1 - x[1]) / xi_h + x[1] / eta_h)
             lambda_34 = xi_h * (1 - x[1]) + eta_h * x[1]
 
             lambda_v = alpha_v * (1 - x[0]) + beta_v * x[0] + gamma_v
-            R_v = -2 * x[0] / ((1 - x[0]) / xi_v + x[0] / eta_v)
+            r_v = -2 * x[0] / ((1 - x[0]) / xi_v + x[0] / eta_v)
             lambda_12 = xi_v * (1 - x[0]) + eta_v * x[0]
 
             for j in range(order - 1):
@@ -48,7 +48,7 @@ class DirectSerendipity(DirectElement):
             for j in range(order - 2):
                 basis_functions.append((1 - x[1]) * x[1] * lambda_12 * lambda_h ** j)
                 basis_entities.append((1, 2))
-            basis_functions.append((1 - x[1]) * x[1] * R_v * lambda_h ** (order - 2))
+            basis_functions.append((1 - x[1]) * x[1] * r_v * lambda_h ** (order - 2))
             basis_entities.append((1, 2))
 
             for j in range(order - 1):
@@ -57,7 +57,7 @@ class DirectSerendipity(DirectElement):
             for j in range(order - 2):
                 basis_functions.append((1 - x[0]) * x[0] * lambda_34 * lambda_v ** j)
                 basis_entities.append((1, 3))
-            basis_functions.append((1 - x[0]) * x[0] * R_h * lambda_v ** (order - 2))
+            basis_functions.append((1 - x[0]) * x[0] * r_h * lambda_v ** (order - 2))
             basis_entities.append((1, 3))
 
         # Functions in interior
