@@ -19,16 +19,18 @@ class DualCiarletElement(CiarletElement):
         super().__init__(reference, order, basis, dofs, domain_dim, range_dim,
                          range_shape=range_shape)
 
-    def get_polynomial_basis(self, reshape=True):
+    def get_polynomial_basis(self, reshape=True, use_legendre=False):
         """Get the polynomial basis for the element."""
         raise ValueError("Polynomial basis not supported for barycentric dual elements.")
 
-    def get_dual_matrix(self):
+    def get_dual_matrix(self, symbolic=True, use_legendre=False):
         """Get the dual matrix."""
         raise ValueError("Dual matrix not supported for barycentric dual elements.")
 
-    def get_basis_functions(self, reshape=True):
+    def get_basis_functions(self, reshape=True, symbolic=True, use_tensor_factorisation=False):
         """Get the basis functions of the element."""
+        assert not use_tensor_factorisation
+
         if self._basis_functions is None:
             from symfem import create_element
 
