@@ -15,7 +15,7 @@ class Lagrange(CiarletElement):
         if order == 0:
             dofs = [
                 PointEvaluation(
-                    tuple(
+                    reference, tuple(
                         sympy.Rational(1, reference.tdim + 1)
                         for i in range(reference.tdim)
                     ),
@@ -28,15 +28,15 @@ class Lagrange(CiarletElement):
             dofs = []
             # Vertices
             for v_n, v in enumerate(reference.vertices):
-                dofs.append(PointEvaluation(v, entity=(0, v_n)))
+                dofs.append(PointEvaluation(reference, v, entity=(0, v_n)))
             # Edges
             for e_n in range(reference.sub_entity_count(1)):
                 entity = reference.sub_entity(1, e_n)
                 for i in range(1, order):
                     dofs.append(
                         PointEvaluation(
-                            tuple(o + entity.axes[0][j] * points[i]
-                                  for j, o in enumerate(entity.origin)),
+                            reference, tuple(o + entity.axes[0][j] * points[i]
+                                             for j, o in enumerate(entity.origin)),
                             entity=(1, e_n)))
             # Faces
             for e_n in range(reference.sub_entity_count(2)):
@@ -45,20 +45,18 @@ class Lagrange(CiarletElement):
                     if len(entity.vertices) == 4 or sum(i) < order:
                         dofs.append(
                             PointEvaluation(
-                                tuple(o + sum(a[j] * points[b]
-                                              for a, b in zip(entity.axes, i[::-1]))
-                                      for j, o in enumerate(entity.origin)),
-                                entity=(2, e_n)))
+                                reference, tuple(
+                                    o + sum(a[j] * points[b] for a, b in zip(entity.axes, i[::-1]))
+                                    for j, o in enumerate(entity.origin)), entity=(2, e_n)))
 
             # Interior
             for i in product(range(1, order), repeat=3):
                 if i[0] + i[1] < order:
                     dofs.append(
                         PointEvaluation(
-                            tuple(o + sum(a[j] * points[b]
-                                          for a, b in zip(reference.axes, i))
-                                  for j, o in enumerate(reference.origin)),
-                            entity=(3, 0)))
+                            reference, tuple(
+                                o + sum(a[j] * points[b] for a, b in zip(reference.axes, i))
+                                for j, o in enumerate(reference.origin)), entity=(3, 0)))
 
         poly = prism_polynomial_set(reference.tdim, 1, order)
         super().__init__(reference, order, poly, dofs, reference.tdim, 1)
@@ -89,7 +87,7 @@ class VectorLagrange(CiarletElement):
             ]
         for p in scalar_space.dofs:
             for d in directions:
-                dofs.append(DotPointEvaluation(p.point, d, entity=p.entity))
+                dofs.append(DotPointEvaluation(reference, p.point, d, entity=p.entity))
 
         super().__init__(
             reference, order,
@@ -105,7 +103,6 @@ class VectorLagrange(CiarletElement):
         return {"variant": self.variant}
 
     names = []
-    # names = ["vector Lagrange", "vP"]
     references = ["prism"]
     min_order = 0
     continuity = "C0"
