@@ -8,7 +8,7 @@ from ..finite_element import CiarletElement
 from ..moments import make_integral_moment_dofs
 from ..polynomials import polynomial_set, Hcurl_polynomials
 from ..functionals import TangentIntegralMoment, IntegralMoment
-from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
+from .lagrange import Lagrange, VectorLagrange
 from .rt import RaviartThomas
 
 
@@ -20,11 +20,11 @@ class NedelecFirstKind(CiarletElement):
         poly += Hcurl_polynomials(reference.tdim, reference.tdim, order)
         dofs = make_integral_moment_dofs(
             reference,
-            edges=(TangentIntegralMoment, DiscontinuousLagrange, order - 1,
+            edges=(TangentIntegralMoment, Lagrange, order - 1,
                    {"variant": variant}),
-            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "covariant",
+            faces=(IntegralMoment, VectorLagrange, order - 2, "covariant",
                    {"variant": variant}),
-            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 3, "covariant",
+            volumes=(IntegralMoment, VectorLagrange, order - 3, "covariant",
                      {"variant": variant}),
         )
 
@@ -49,7 +49,7 @@ class NedelecSecondKind(CiarletElement):
 
         dofs = make_integral_moment_dofs(
             reference,
-            edges=(TangentIntegralMoment, DiscontinuousLagrange, order, {"variant": variant}),
+            edges=(TangentIntegralMoment, Lagrange, order, {"variant": variant}),
             faces=(IntegralMoment, RaviartThomas, order - 1, "covariant", {"variant": variant}),
             volumes=(IntegralMoment, RaviartThomas, order - 2, "covariant", {"variant": variant}),
         )
