@@ -26,7 +26,7 @@ class Transition(CiarletElement):
         dofs = []
         poly = polynomial_set(reference.tdim, 1, 1)
         for v_n, v in enumerate(reference.reference_vertices):
-            dofs.append(PointEvaluation(v, entity=(0, v_n)))
+            dofs.append(PointEvaluation(reference, v, entity=(0, v_n)))
 
         for edim in range(1, 4):
             for e_n in range(reference.sub_entity_count(edim)):
@@ -45,7 +45,7 @@ class Transition(CiarletElement):
                 for i in product(range(1, entity_order), repeat=edim):
                     if sum(i) < entity_order:
                         pt = entity.get_point([points[j] for j in i])
-                        dofs.append(PointEvaluation(pt, entity=(edim, e_n)))
+                        dofs.append(PointEvaluation(reference, pt, entity=(edim, e_n)))
 
                 # Basis
                 if entity_order > edim:
@@ -65,7 +65,7 @@ class Transition(CiarletElement):
                             if i in reference.edges[e_n]:
                                 bubble *= f
                     space = Lagrange(entity, entity_order - edim - 1, variant=variant)
-                    vars = []
+                    variables = []
                     origin = entity.vertices[0]
                     used = []
                     for p in entity.vertices[1:]:
@@ -73,8 +73,8 @@ class Transition(CiarletElement):
                         while p[i] == origin[i] or origin[i] == 1 or i in used:
                             i += 1
                         used.append(i)
-                        vars.append(origin[i] + (p[i] - origin[i]) * x[i])
-                    poly += [subs(f, x, vars) * bubble for f in space.get_basis_functions()]
+                        variables.append(origin[i] + (p[i] - origin[i]) * x[i])
+                    poly += [subs(f, x, variables) * bubble for f in space.get_basis_functions()]
 
         super().__init__(
             reference, order, poly, dofs, reference.tdim, 1
