@@ -3,15 +3,15 @@
 import sympy
 import warnings
 import numpy
+import math
 from itertools import product
 from .symbolic import x, subs, sym_sum, PiecewiseFunction, to_sympy, to_float, symequal, sym_product
 from .calculus import diff
 from .vectors import vsub
 from .basis_function import ElementBasisFunction
-from .legendre import evaluate_legendre_basis, get_legendre_basis
 
 
-class NoTensorProduct(BaseException):
+class NoTensorProduct(Exception):
     """Error for element without a tensor representation."""
 
     def __init__(self):
@@ -179,7 +179,7 @@ class FiniteElement:
                         f += deriv_f
                         deriv_g = [diff(d, i) for d in deriv_g for i in x[:self.reference.tdim]]
                         g += deriv_g
-                elif continuity == "H(div)":
+                elif continuity == "H(div)" or continuity == "inner H(div)":
                     f = f[0]
                     g = g[0]
                 elif continuity == "H(curl)":
@@ -205,9 +205,6 @@ class FiniteElement:
                             assert dim == 2
                             f = [f[4], f[8]]
                             g = [g[4], g[8]]
-                elif continuity == "inner H(div)":
-                    f = f[0]
-                    g = g[0]
                 elif continuity == "integral inner H(div)":
                     f = f[0].integrate((to_sympy(x[1]), 0, 1))
                     g = g[0].integrate((to_sympy(x[1]), 0, 1))
@@ -254,27 +251,14 @@ class CiarletElement(FiniteElement):
         self._basis_functions = None
         self._reshaped_basis_functions = None
         self._dual_inv = None
-        self._dual_inv_legendre = None
-
-    @property
-    def _can_use_legendre(self):
-        return evaluate_legendre_basis(numpy.array(self.reference.vertices), self._basis,
-                                       self.reference) is not None
 
     def entity_dofs(self, entity_dim, entity_number):
         """Get the numbers of the DOFs associated with the given entity."""
         return [i for i, j in enumerate(self.dofs) if j.entity == (entity_dim, entity_number)]
 
-    def get_polynomial_basis(self, reshape=True, use_legendre=False):
+    def get_polynomial_basis(self, reshape=True):
         """Get the symbolic polynomial basis for the element."""
-        if use_legendre and not self._can_use_legendre:
-            use_legendre = False
-            warnings.warn("Cannot calculate Legendre basis for this element. "
-                          "Using standard basis instead.")
-        if use_legendre:
-            basis = [to_sympy(i) for i in get_legendre_basis(self._basis, self.reference)]
-        else:
-            basis = [to_sympy(i) for i in self._basis]
+        basis = [to_sympy(i) for i in self._basis]
 
         if reshape and self.range_shape is not None:
             if len(self.range_shape) != 2:
@@ -285,51 +269,31 @@ class CiarletElement(FiniteElement):
                  for i in range(self.range_shape[0])]) for b in basis]
         return basis
 
-    def get_tabulated_polynomial_basis(self, points, symbolic=True, use_legendre=False):
+    def get_tabulated_polynomial_basis(self, points, symbolic=True):
         """Get the value of the polynomial basis at the given points."""
-        if use_legendre and not self._can_use_legendre:
-            use_legendre = False
-            warnings.warn("Cannot calculate Legendre basis for this element. "
-                          "Using standard basis instead.")
         if symbolic:
             return [
-                [subs(f, x, p) for f in self.get_polynomial_basis(
-                    use_legendre=use_legendre)]
+                [subs(f, x, p) for f in self.get_polynomial_basis()]
                 for p in points]
         else:
-            if use_legendre:
-                return evaluate_legendre_basis(points, self._basis, self.reference)
-            else:
-                return numpy.array([
-                    [to_float(subs(f, x, p)) for f in self.get_polynomial_basis(
-                        use_legendre=use_legendre)]
-                    for p in points])
+            return numpy.array([
+                [to_float(subs(f, x, p)) for f in self.get_polynomial_basis()]
+                for p in points])
 
-    def tabulate_basis(self, points, order="xyzxyz", symbolic=True, use_legendre=False):
+    def tabulate_basis(self, points, order="xyzxyz", symbolic=True):
         """Evaluate the basis functions of the element at the given points."""
-        if use_legendre and not self._can_use_legendre:
-            use_legendre = False
-            warnings.warn("Cannot calculate Legendre basis for this element. "
-                          "Using standard basis instead.")
-
         if symbolic:
             return super().tabulate_basis(points, order, symbolic=True)
 
         assert not symbolic
 
         tabulated_polyset = self.get_tabulated_polynomial_basis(
-            points, symbolic=False, use_legendre=use_legendre)
+            points, symbolic=False)
 
-        if use_legendre:
-            if self._dual_inv_legendre is None:
-                dual_mat = self.get_dual_matrix(symbolic=False, use_legendre=True)
-                self._dual_inv_legendre = numpy.linalg.inv(dual_mat)
-            dual_inv = self._dual_inv_legendre
-        else:
-            if self._dual_inv is None:
-                dual_mat = self.get_dual_matrix(symbolic=False, use_legendre=False)
-                self._dual_inv = numpy.linalg.inv(dual_mat)
-            dual_inv = self._dual_inv
+        if self._dual_inv is None:
+            dual_mat = self.get_dual_matrix(symbolic=False)
+            self._dual_inv = numpy.linalg.inv(dual_mat)
+        dual_inv = self._dual_inv
 
         if self.range_dim == 1:
             return numpy.dot(tabulated_polyset, dual_inv.transpose())
@@ -360,11 +324,11 @@ class CiarletElement(FiniteElement):
             ])
         raise ValueError(f"Unknown order: {order}")
 
-    def get_dual_matrix(self, symbolic=True, use_legendre=False):
+    def get_dual_matrix(self, symbolic=True):
         """Get the dual matrix."""
         if symbolic:
             mat = []
-            for b in self.get_polynomial_basis(use_legendre=use_legendre):
+            for b in self.get_polynomial_basis():
                 row = []
                 for d in self.dofs:
                     row.append(to_sympy(d.eval(to_sympy(b), symbolic=symbolic)))
@@ -375,7 +339,7 @@ class CiarletElement(FiniteElement):
                 if d.get_points_and_weights is None:
                     warnings.warn("Cannot numerically evaluate all the DOFs in this element. "
                                   "Converting symbolic evaluations instead (this may be slow).")
-                    mat = self.get_dual_matrix(symbolic=True, use_legendre=use_legendre)
+                    mat = self.get_dual_matrix(symbolic=True)
                     return numpy.array(
                         [[float(j) for j in mat.row(i)] for i in range(mat.rows)]
                     )
@@ -383,7 +347,7 @@ class CiarletElement(FiniteElement):
             for i, d in enumerate(self.dofs):
                 p, w = d.get_points_and_weights()
                 mat[:, i] = numpy.dot(w, self.get_tabulated_polynomial_basis(
-                    p, symbolic=False, use_legendre=use_legendre))
+                    p, symbolic=False))
             return mat
 
     def init_kwargs(self):
@@ -424,30 +388,29 @@ class CiarletElement(FiniteElement):
 
         return self._basis_functions
 
-    def map_to_cell(self, vertices, basis=None, map=None, inverse_map=None):
+    def map_to_cell(self, vertices, basis=None, forward_map=None, inverse_map=None):
         """Map the basis onto a cell using the appropriate mapping for the element."""
         if basis is None:
             basis = self.get_basis_functions()
-        if map is None:
-            map = self.reference.get_map_to(vertices)
+        if forward_map is None:
+            forward_map = self.reference.get_map_to(vertices)
         if inverse_map is None:
             inverse_map = self.reference.get_inverse_map_to(vertices)
 
         if isinstance(basis[0], PiecewiseFunction):
             pieces = [[] for i in basis]
             for i, j in enumerate(basis[0].pieces):
-                new_i = [subs(map, x, k) for k in j[0]]
+                new_i = [subs(forward_map, x, k) for k in j[0]]
                 for k, f in enumerate(self.map_to_cell(vertices, [b.pieces[i][1] for b in basis])):
                     pieces[k].append((new_i, f))
             return [PiecewiseFunction(p) for p in pieces]
 
         if isinstance(basis[0], (list, tuple)) and isinstance(basis[0][0], PiecewiseFunction):
             for b in basis:
-                pieces = [[] for f in b]
                 for f in b:
                     for i, j in enumerate(f.pieces):
                         assert j[0] == basis[0][0].pieces[i][0]
-            new_tris = [[subs(map, x, k) for k in p[0]] for p in basis[0][0].pieces]
+            new_tris = [[subs(forward_map, x, k) for k in p[0]] for p in basis[0][0].pieces]
             output_pieces = []
             for p in range(len(basis[0][0].pieces)):
                 piece_basis = []
@@ -456,7 +419,7 @@ class CiarletElement(FiniteElement):
                         f.pieces[p][1] for f in b
                     ])
                 output_pieces.append(self.map_to_cell(
-                    vertices, piece_basis, map, inverse_map))
+                    vertices, piece_basis, forward_map, inverse_map))
 
             return [PiecewiseFunction(list(zip(new_tris, fs)))
                     for fs in zip(*output_pieces)]
@@ -475,7 +438,7 @@ class CiarletElement(FiniteElement):
                 for ds in dofs_by_type.values():
                     mapped_dofs = self.dofs[ds[0]].perform_mapping(
                         [basis[d] for d in ds],
-                        map, inverse_map, self.reference.tdim)
+                        forward_map, inverse_map, self.reference.tdim)
                     for d_n, d in zip(ds, mapped_dofs):
                         out[d_n] = d
 
@@ -488,14 +451,28 @@ class CiarletElement(FiniteElement):
         super().test()
         self.test_functional_entities()
         self.test_functionals()
+        self.test_dof_points()
+
+    def test_dof_points(self):
+        """Test that DOF points are valid."""
+        for d in self.dofs:
+            p = d.dof_point()
+            assert len(p) == self.reference.gdim
+            for i in p:
+                if i is None:
+                    break
+                else:
+                    assert not math.isnan(float(i))
+            else:
+                assert self.reference.contains(p)
 
     def test_functional_entities(self):
         """Test that the dof entities are valid and match the references of integrals."""
         for dof in self.dofs:
             dim, entity = dof.entity
             assert entity < self.reference.sub_entity_count(dim)
-            if hasattr(dof, "reference"):
-                assert dim == dof.reference.tdim
+            if hasattr(dof, "integral_domain"):
+                assert dim == dof.integral_domain.tdim
 
     def test_functionals(self):
         """Test that the functionals are satisfied by the basis functions."""
