@@ -24,34 +24,36 @@ def identity(f, map, inverse_map, tdim):
 def covariant(f, map, inverse_map, tdim):
     """Map H(curl) functions."""
     g = subs(f, x, inverse_map)
-    Jinv = sympy.Matrix([[diff(i, x[j]) for j in range(len(map))] for i in inverse_map]).transpose()
-    return tuple(vdot(Jinv.row(i), g) for i in range(Jinv.rows))
+    j_inv = sympy.Matrix([[diff(i, x[j]) for j in range(len(map))]
+                          for i in inverse_map]).transpose()
+    return tuple(vdot(j_inv.row(i), g) for i in range(j_inv.rows))
 
 
 def contravariant(f, map, inverse_map, tdim):
     """Map H(div) functions."""
     g = subs(f, x, inverse_map)
-    J = sympy.Matrix([[diff(i, x[j]) for j in range(tdim)] for i in map])
-    J /= _det(J)
-    return tuple(vdot(J.row(i), g) for i in range(J.rows))
+    jacobian = sympy.Matrix([[diff(i, x[j]) for j in range(tdim)] for i in map])
+    jacobian /= _det(jacobian)
+    return tuple(vdot(jacobian.row(i), g) for i in range(jacobian.rows))
 
 
 def double_covariant(f, map, inverse_map, tdim):
     """Map matrix functions."""
     g = subs(f, x, inverse_map)
-    Jinv = sympy.Matrix([[diff(i, x[j]) for j in range(len(map))] for i in inverse_map]).transpose()
+    j_inv = sympy.Matrix([[diff(i, x[j]) for j in range(len(map))]
+                          for i in inverse_map]).transpose()
 
-    G = sympy.Matrix([g[i * tdim: (i + 1) * tdim] for i in range(tdim)])
-    out = Jinv * G * Jinv.transpose()
+    g_mat = sympy.Matrix([g[i * tdim: (i + 1) * tdim] for i in range(tdim)])
+    out = j_inv * g_mat * j_inv.transpose()
     return tuple(out[i] for i in range(out.rows * out.cols))
 
 
 def double_contravariant(f, map, inverse_map, tdim):
     """Map matrix functions."""
     g = subs(f, x, inverse_map)
-    J = sympy.Matrix([[diff(i, x[j]) for j in range(tdim)] for i in map])
-    J /= _det(J)
+    jacobian = sympy.Matrix([[diff(i, x[j]) for j in range(tdim)] for i in map])
+    jacobian /= _det(jacobian)
 
-    G = sympy.Matrix([g[i * tdim: (i + 1) * tdim] for i in range(tdim)])
-    out = J * G * J.transpose()
+    g_mat = sympy.Matrix([g[i * tdim: (i + 1) * tdim] for i in range(tdim)])
+    out = jacobian * g_mat * jacobian.transpose()
     return tuple(out[i] for i in range(out.rows * out.cols))
