@@ -3,43 +3,43 @@
 import sympy
 
 
-def equispaced(N):
+def equispaced(n):
     """Get equispaced points and weights.
 
     Parameters
     ----------
-    N : int
+    n : int
         Number of points
     """
-    return ([sympy.Rational(i, N - 1) for i in range(N)],
-            [sympy.Rational(1, 2*(N-1)) if i == 0 or i == N - 1 else sympy.Rational(1, N-1)
-             for i in range(N)])
+    return ([sympy.Rational(i, n - 1) for i in range(n)],
+            [sympy.Rational(1, 2*(n-1)) if i == 0 or i == n - 1 else sympy.Rational(1, n-1)
+             for i in range(n)])
 
 
-def lobatto(N):
+def lobatto(n):
     """Get Gauss-Lobatto-Legendre points and weights.
 
     Parameters
     ----------
-    N : int
+    n : int
         Number of points
     """
-    if N == 2:
+    if n == 2:
         return ([0, 1],
                 [sympy.Rational(1, 2), sympy.Rational(1, 2)])
-    if N == 3:
+    if n == 3:
         return ([0, sympy.Rational(1, 2), 1],
                 [sympy.Rational(1, 6), sympy.Rational(2, 3), sympy.Rational(1, 6)])
-    if N == 4:
+    if n == 4:
         return ([0, (1 - 1 / sympy.sqrt(5)) / 2, (1 + 1 / sympy.sqrt(5)) / 2, 1],
                 [sympy.Rational(1, 12), sympy.Rational(5, 12), sympy.Rational(5, 12),
                  sympy.Rational(1, 12)])
-    if N == 5:
+    if n == 5:
         return ([0, (1 - sympy.sqrt(3) / sympy.sqrt(7)) / 2, sympy.Rational(1, 2),
                  (1 + sympy.sqrt(3) / sympy.sqrt(7)) / 2, 1],
                 [sympy.Rational(1, 20), sympy.Rational(49, 180), sympy.Rational(16, 45),
                  sympy.Rational(49, 180), sympy.Rational(1, 20)])
-    if N == 6:
+    if n == 6:
         return ([0,
                  (1 - sympy.sqrt(sympy.Rational(1, 3) + (2 * sympy.sqrt(7) / 21))) / 2,
                  (1 - sympy.sqrt(sympy.Rational(1, 3) - (2 * sympy.sqrt(7) / 21))) / 2,
@@ -48,7 +48,7 @@ def lobatto(N):
                  1],
                 [sympy.Rational(1, 30), (14 - sympy.sqrt(7)) / 60, (14 + sympy.sqrt(7)) / 60,
                  (14 + sympy.sqrt(7)) / 60, (14 - sympy.sqrt(7)) / 60, sympy.Rational(1, 30)])
-    if N == 7:
+    if n == 7:
         return ([0,
                  (1 - sympy.sqrt((5 + 2 * sympy.sqrt(5) / sympy.sqrt(3)) / 11)) / 2,
                  (1 - sympy.sqrt((5 - 2 * sympy.sqrt(5) / sympy.sqrt(3)) / 11)) / 2,
@@ -66,43 +66,43 @@ def lobatto(N):
     raise NotImplementedError()
 
 
-def radau(N):
+def radau(n):
     """Get Radau points and weights.
 
     Parameters
     ----------
-    N : int
+    n : int
         Number of points
     """
-    if N == 2:
+    if n == 2:
         return ([0, sympy.Rational(2, 3)],
                 [sympy.Rational(1, 4), sympy.Rational(3, 4)])
-    if N == 3:
+    if n == 3:
         return ([0, (6 - sympy.sqrt(6)) / 10, (6 + sympy.sqrt(6)) / 10],
                 [sympy.Rational(1, 9), (16 + sympy.sqrt(6)) / 36, (16 - sympy.sqrt(6)) / 36])
     raise NotImplementedError()
 
 
-def legendre(N):
+def legendre(n):
     """Get Gauss-Legendre points and weights.
 
     Parameters
     ----------
-    N : int
+    n : int
         Number of points
     """
-    if N == 1:
+    if n == 1:
         return ([sympy.Rational(1, 2)], [1])
-    if N == 2:
+    if n == 2:
         return ([(3 - sympy.sqrt(3)) / 6, (3 + sympy.sqrt(3)) / 6],
                 [sympy.Rational(1, 2), sympy.Rational(1, 2)])
-    if N == 3:
+    if n == 3:
         return ([(5 - sympy.sqrt(15)) / 10, sympy.Rational(1, 2), (5 + sympy.sqrt(15)) / 10],
                 [sympy.Rational(5, 18), sympy.Rational(4, 9), sympy.Rational(5, 18)])
     raise NotImplementedError()
 
 
-def get_quadrature(rule, N):
+def get_quadrature(rule, n):
     """Get quadrature points and weights.
 
     Parameters
@@ -110,15 +110,15 @@ def get_quadrature(rule, N):
     rule : str
         The quadrature rule.
         Supported values: equispaced, lobatto, radau, legendre
-    N : int
+    n : int
         Number of points
     """
     if rule == "equispaced":
-        return equispaced(N)
+        return equispaced(n)
     if rule == "lobatto":
-        return lobatto(N)
+        return lobatto(n)
     if rule == "radau":
-        return radau(N)
+        return radau(n)
     if rule == "legendre":
-        return legendre(N)
+        return legendre(n)
     raise ValueError(f"Unknown quadrature rule: {rule}")
