@@ -25,7 +25,7 @@ class Reference:
         return tuple(o + sym_sum(a[i] * b for a, b in zip(self.axes, reference_coords))
                      for i, o in enumerate(self.origin))
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
         raise NotImplementedError
 
@@ -158,6 +158,10 @@ class Reference:
                 return True
         return False
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        raise NotImplementedError
+
 
 class Point(Reference):
     """A point."""
@@ -179,9 +183,9 @@ class Point(Reference):
         """Get the default reference for this cell type."""
         return Point(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return subs(f, t, self.vertices[0])
+        return subs(f, vars, self.vertices[0])
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -205,6 +209,11 @@ class Point(Reference):
         """Calculate the volume."""
         return 0
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.tdim == 0:
+            return point in self.vertices
+
 
 class Interval(Reference):
     """An interval."""
@@ -226,9 +235,9 @@ class Interval(Reference):
         """Get the default reference for this cell type."""
         return Interval(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (f * self.jacobian()).integrate((t[0], 0, 1))
+        return (f * self.jacobian()).integrate((vars[0], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -256,6 +265,12 @@ class Interval(Reference):
         """Calculate the volume."""
         return self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return 0 <= point[0] <= 1
+
 
 class Triangle(Reference):
     """A triangle."""
@@ -277,11 +292,10 @@ class Triangle(Reference):
         """Get the default reference for this cell type."""
         return Triangle(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (
-            (f * self.jacobian()).integrate((t[1], 0, 1 - t[0])).integrate((t[0], 0, 1))
-        )
+        return (f * self.jacobian()).integrate(
+            (vars[1], 0, 1 - vars[0]), (vars[0], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -322,6 +336,12 @@ class Triangle(Reference):
         """Calculate the volume."""
         return sympy.Rational(1, 2) * self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return 0 <= point[0] and 0 <= point[1] and sum(point) <= 1
+
 
 class Tetrahedron(Reference):
     """A tetrahedron."""
@@ -347,14 +367,10 @@ class Tetrahedron(Reference):
         """Get the default reference for this cell type."""
         return Tetrahedron(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (
-            (f * self.jacobian())
-            .integrate((t[2], 0, 1 - t[0] - t[1]))
-            .integrate((t[1], 0, 1 - t[0]))
-            .integrate((t[0], 0, 1))
-        )
+        return (f * self.jacobian()).integrate(
+            (vars[0], 0, 1 - vars[1] - vars[2]), (vars[1], 0, 1 - vars[2]), (vars[2], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -395,6 +411,12 @@ class Tetrahedron(Reference):
         """Calculate the volume."""
         return sympy.Rational(1, 6) * self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return 0 <= point[0] and 0 <= point[1] and 0 <= point[2] and sum(point) <= 1
+
 
 class Quadrilateral(Reference):
     """A quadrilateral."""
@@ -416,9 +438,9 @@ class Quadrilateral(Reference):
         """Get the default reference for this cell type."""
         return Quadrilateral(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (f * self.jacobian()).integrate((t[1], 0, 1)).integrate((t[0], 0, 1))
+        return (f * self.jacobian()).integrate((vars[1], 0, 1), (vars[0], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -479,6 +501,12 @@ class Quadrilateral(Reference):
         """Calculate the volume."""
         return self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return 0 <= point[0] <= 1 and 0 <= point[1] <= 1
+
 
 class Hexahedron(Reference):
     """A hexahedron."""
@@ -511,14 +539,10 @@ class Hexahedron(Reference):
         """Get the default reference for this cell type."""
         return Hexahedron(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (
-            (f * self.jacobian())
-            .integrate((t[2], 0, 1))
-            .integrate((t[1], 0, 1))
-            .integrate((t[0], 0, 1))
-        )
+        return (f * self.jacobian()).integrate(
+            (vars[2], 0, 1), (vars[1], 0, 1), (vars[0], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -573,6 +597,12 @@ class Hexahedron(Reference):
         """Calculate the volume."""
         return self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return 0 <= point[0] <= 1 and 0 <= point[1] <= 1 and 0 <= point[2] <= 1
+
 
 class Prism(Reference):
     """A (triangular) prism."""
@@ -608,14 +638,10 @@ class Prism(Reference):
         """Get the default reference for this cell type."""
         return Prism(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (
-            (f * self.jacobian())
-            .integrate((t[2], 0, 1))
-            .integrate((t[1], 0, 1 - t[0]))
-            .integrate((t[0], 0, 1))
-        )
+        return(f * self.jacobian()).integrate(
+            (vars[2], 0, 1), (vars[1], 0, 1 - vars[0]), (vars[0], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -666,6 +692,13 @@ class Prism(Reference):
         """Calculate the volume."""
         return sympy.Rational(1, 2) * self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return (point[0] >= 0 and point[1] >= 0 and point[2] >= 0
+                and point[2] <= 1 and point[0] + point[1] <= 1)
+
 
 class Pyramid(Reference):
     """A (square-based) pyramid."""
@@ -701,14 +734,10 @@ class Pyramid(Reference):
         """Get the default reference for this cell type."""
         return Pyramid(self.reference_vertices)
 
-    def integral(self, f):
+    def integral(self, f, vars=t):
         """Calculate the integral over the element."""
-        return (
-            (f * self.jacobian())
-            .integrate((t[2], 0, 1))
-            .integrate((t[1], 0, 1 - t[0]))
-            .integrate((t[0], 0, 1))
-        )
+        return (f * self.jacobian()).integrate(
+            (vars[0], 0, 1 - vars[2]), (vars[1], 0, 1 - vars[2]), (vars[2], 0, 1))
 
     def get_map_to(self, vertices):
         """Get the map from the reference to a cell."""
@@ -763,6 +792,13 @@ class Pyramid(Reference):
         """Calculate the volume."""
         return sympy.Rational(1, 3) * self.jacobian()
 
+    def contains(self, point):
+        """Check is a point is contained in the reference."""
+        if self.vertices != self.reference_vertices:
+            raise NotImplementedError
+        return (point[0] >= 0 and point[1] >= 0 and point[2] >= 0
+                and point[0] + point[2] <= 1 and point[1] + point[2] <= 1)
+
 
 class DualPolygon(Reference):
     """A polygon on a barycentric dual grid."""
